
/*
 * The JTS Topology Suite is a collection of Java classes that
 * implement the fundamental operations required to validate a given
 * geo-spatial data set to a known topological specification.
 *
 * Copyright (C) 2001 Vivid Solutions
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * For more information, contact:
 *
 *     Vivid Solutions
 *     Suite #1A
 *     2328 Government Street
 *     Victoria BC  V8T 5G5
 *     Canada
 *
 *     (250)385-6040
 *     www.vividsolutions.com
 */
package com.vividsolutions.jts.geom;

/**
 * The CoordinateSequence implementation that Geometries use by default. In this
 * implementation, Coordinates returned by #toArray and #get are live -- parties
 * that change them are actually changing the DefaultCoordinateSequence's 
 * underlying data.
 *
 * @version 1.4.0
 */
class DefaultCoordinateSequence implements CoordinateSequence {
    private Coordinate[] coordinates;

    /**
     * Constructs a DefaultCoordinateSequence based on the given array (the
     * array is not copied).
     */
    public DefaultCoordinateSequence(Coordinate[] coordinates) {
        if (Geometry.hasNullElements(coordinates)) {
            throw new IllegalArgumentException("Null coordinate");
        }
        this.coordinates = coordinates;
    }

    public Coordinate getCoordinate(int i) {
        return coordinates[i];
    }

    public Object clone() {
        Coordinate[] cloneCoordinates = new Coordinate[size()];
        for (int i = 0; i < coordinates.length; i++) {
            cloneCoordinates[i] = (Coordinate) coordinates[i].clone();
        }

        return new DefaultCoordinateSequence(cloneCoordinates);
    }

    public int size() {
        return coordinates.length;
    }

    public Coordinate[] toCoordinateArray() {
        return coordinates;
    }

    public String toString()
    {
      StringBuffer strBuf = new StringBuffer();
      strBuf.append("(");
      for (int i = 0; i < coordinates.length; i++) {
        if (i > 0) strBuf.append(", ");
        strBuf.append(coordinates[i]);
      }
      strBuf.append(")");
      return strBuf.toString();
    }

}
